translate.storage.directory.Directory

Package translate :: Package storage :: Module directory :: Class Directory |
[hide private]
[frames] | no frames]

# Class Directory

source code

This class represents a directory.

Instance Methods | [hide private]
__init__(self, dir=None) | source code
file_iter(self) Iterator over (dir, filename) for all files in this directory. | source code
getfiles(self) Returns a list of (dir, filename) tuples for all the file names in this directory. | source code
unit_iter(self) Iterator over all the units in all the files in this directory. | source code
getunits(self) List of all the units in all the files in this directory. | source code
scanfiles(self) Populate the internal file data. | source code